@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2021 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2022 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -227,9 +227,6 @@ LIBHARP_API int harp_collocation_result_new(harp_collocation_result **new_colloc
 
 /** Remove a collocation result set
  * \param collocation_result Result set that will be removed.
- * \return
- *   \arg \c 0, Success.
- *   \arg \c -1, Error occurred (check #harp_errno).
  */
 LIBHARP_API void harp_collocation_result_delete(harp_collocation_result *collocation_result)
 {
@@ -401,8 +398,8 @@ static int compare_by_b(const void *a, const void *b)
     /* If b is equal, then further sort by a to get a fixed ordering. */
     if (pair_a->product_index_a != pair_b->product_index_a)
     {
-        return strcmp(sort_dataset_a->source_product[pair_a->product_index_b],
-                      sort_dataset_a->source_product[pair_b->product_index_b]);
+        return strcmp(sort_dataset_a->source_product[pair_a->product_index_a],
+                      sort_dataset_a->source_product[pair_b->product_index_a]);
     }
     if (pair_a->sample_index_a < pair_b->sample_index_a)
     {
