@@ -178,8 +178,8 @@ void harp_inverse_euler_transformation_from_spherical_line(harp_euler_transforma
                                                            const harp_spherical_line *line);
 int8_t harp_spherical_line_spherical_line_relationship(const harp_spherical_line *linea,
                                                        const harp_spherical_line *lineb);
-int harp_spherical_line_from_spherical_points(harp_spherical_line *line, const harp_spherical_point *point_begin,
-                                              const harp_spherical_point *point_end);
+void harp_spherical_line_from_spherical_points(harp_spherical_line *line, const harp_spherical_point *point_begin,
+                                               const harp_spherical_point *point_end);
 void harp_spherical_line_spherical_line_intersection_point(const harp_spherical_line *line_p,
                                                            const harp_spherical_line *line_q,
                                                            harp_spherical_point *point_u);
@@ -206,7 +206,7 @@ int harp_spherical_polygon_check(const harp_spherical_polygon *polygon);
 void harp_spherical_polygon_delete(harp_spherical_polygon *polygon);
 int harp_spherical_polygon_from_latitude_longitude_bounds(long measurement_id, long num_vertices,
                                                           const double *latitude_bounds, const double *longitude_bounds,
-                                                          harp_spherical_polygon **new_polygon);
+                                                          int check_polygon, harp_spherical_polygon **new_polygon);
 int harp_spherical_polygon_centre(harp_vector3d *vector_centre, const harp_spherical_polygon *polygon);
 int harp_spherical_polygon_contains_point(const harp_spherical_polygon *polygon, const harp_spherical_point *point);
 int8_t harp_spherical_polygon_spherical_line_relationship(const harp_spherical_polygon *polygon,
