@@ -91,6 +91,9 @@ int harp_ingestion_module_npp_suomi_crimss_l2_init(void);
 int harp_ingestion_module_npp_suomi_omps_profiles_l2_init(void);
 int harp_ingestion_module_npp_suomi_omps_totals_l2_init(void);
 int harp_ingestion_module_npp_suomi_viirs_l2_init(void);
+int harp_ingestion_module_oco_l3co2_init(void);
+int harp_ingestion_module_oco_ltco2_init(void);
+int harp_ingestion_module_oco_ltsif_init(void);
 int harp_ingestion_module_omi_l2_init(void);
 int harp_ingestion_module_omi_l3_init(void);
 int harp_ingestion_module_osiris_l2_init(void);
@@ -157,6 +160,9 @@ static module_init_func_t *module_init_func[] = {
     harp_ingestion_module_npp_suomi_omps_profiles_l2_init,
     harp_ingestion_module_npp_suomi_omps_totals_l2_init,
     harp_ingestion_module_npp_suomi_viirs_l2_init,
+    harp_ingestion_module_oco_l3co2_init,
+    harp_ingestion_module_oco_ltco2_init,
+    harp_ingestion_module_oco_ltsif_init,
     harp_ingestion_module_omi_l2_init,
     harp_ingestion_module_omi_l3_init,
     harp_ingestion_module_osiris_l2_init,
